==> wolf-2.2.21-sources.jar: cn/com/duiba/wolf/dubbo/InitOperation.java <==
package cn.com.duiba.wolf.dubbo;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

import org.apache.commons.lang.math.NumberUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanInfoFactory;
import org.springframework.context.ApplicationContext;

import cn.com.duiba.wolf.perf.timeprofile.DBTimeProfile;

import com.google.common.base.Preconditions;

/**
 * <pre>
 * Created by xuezhaoming-inter12 on 14-10-10.上午11:53
 * </pre>
 */
public class InitOperation {

    private static final Logger     LOG               = LoggerFactory.getLogger(InitOperation.class);

    private static volatile boolean initialized       = false;

    private static final String     DEFAULT_PATH      = "/META-INF/wolf/wolf.properties";

    public static final int         DEFAULT_THRESHOLD = 500;

    private InitOperation(){}

    public static synchronized void init() {
        if (initialized) {
            return;
        }

        LOG.info(" ----------- start class file  duplicate check   -----------");

        final String configPath = DEFAULT_PATH;

        VersionCheck.checkDuplicate(Logger.class);// sl4j
        VersionCheck.checkDuplicate(Preconditions.class);// guava
        VersionCheck.checkDuplicate(ApplicationContext.class);// spring-context
        VersionCheck.checkDuplicate(BeanInfoFactory.class);// spring-bean
        VersionCheck.checkDuplicate("org.junit.Assume.class");// junit
//        VersionCheck.checkDuplicate(ClassPool.class);// javassist
        VersionCheck.checkDuplicate(DEFAULT_PATH);// properties
        VersionCheck.checkDuplicate(configPath);// properties

        LOG.info(" ----------- end class file  duplicate check   -----------");

        LOG.info(" ----------- start init config  -----------");
        int threshold = DEFAULT_THRESHOLD;
        InputStream propertiesInputStream = InitOperation.class.getResourceAsStream(configPath);

        if(propertiesInputStream != null) {
            Properties properties = new Properties();
            try {
                properties.load(propertiesInputStream);
                String thresholdStr = properties.getProperty("timeprofile.threshold");

                if (NumberUtils.isNumber(thresholdStr)) {
                    threshold = Integer.valueOf(thresholdStr);
                }
            } catch (Exception e) {

                LOG.error(" ----------- init time profile  error !  -----------" + EnvInfo.getEnvInfo(), e);

            } finally {
                try {
                    propertiesInputStream.close();
                } catch (IOException e) {
                    //Ignore
                }

                LOG.info("threshold info {}", threshold);
            }
        }
        DBTimeProfile.setThreshold(threshold);

        LOG.info(" ----------- end of  init   config  -----------");
        initialized = true;
    }

}

==> wolf-2.2.45-sources.jar: cn/com/duiba/wolf/dubbo/InitOperation.java <==
package cn.com.duiba.wolf.dubbo;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

import org.apache.commons.lang.math.NumberUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanInfoFactory;
import org.springframework.context.ApplicationContext;

import cn.com.duiba.wolf.perf.timeprofile.DBTimeProfile;

import com.google.common.base.Preconditions;

/**
 * <pre>
 * Created by xuezhaoming-inter12 on 14-10-10.上午11:53
 * </pre>
 */
public class InitOperation {

    private static final Logger     LOG               = LoggerFactory.getLogger(InitOperation.class);

    private static volatile boolean initialized       = false;

    private static final String     DEFAULT_PATH      = "/META-INF/wolf/wolf.properties";

    public static final int         DEFAULT_THRESHOLD = 500;

    private InitOperation(){}

    public static synchronized void init() {
        if (initialized) {
            return;
        }

        LOG.debug(" ----------- start class file  duplicate check   -----------");

        final String configPath = DEFAULT_PATH;

        VersionCheck.checkDuplicate(Logger.class);// sl4j
        VersionCheck.checkDuplicate(Preconditions.class);// guava
        VersionCheck.checkDuplicate(ApplicationContext.class);// spring-context
        VersionCheck.checkDuplicate(BeanInfoFactory.class);// spring-bean
        VersionCheck.checkDuplicate("org.junit.Assume.class");// junit
//        VersionCheck.checkDuplicate(ClassPool.class);// javassist
        VersionCheck.checkDuplicate(DEFAULT_PATH);// properties
        VersionCheck.checkDuplicate(configPath);// properties

        LOG.debug(" ----------- end class file  duplicate check   -----------");

        LOG.debug(" ----------- start init config  -----------");
        int threshold = DEFAULT_THRESHOLD;
        InputStream propertiesInputStream = InitOperation.class.getResourceAsStream(configPath);

        if(propertiesInputStream != null) {
            Properties properties = new Properties();
            try {
                properties.load(propertiesInputStream);
                String thresholdStr = properties.getProperty("timeprofile.threshold");

                if (NumberUtils.isNumber(thresholdStr)) {
                    threshold = Integer.valueOf(thresholdStr);
                }
            } catch (Exception e) {

                LOG.error(" ----------- init time profile  error !  -----------" + EnvInfo.getEnvInfo(), e);

            } finally {
                try {
                    propertiesInputStream.close();
                } catch (IOException e) {
                    //Ignore
                }

                LOG.info("threshold info {}", threshold);
            }
        }
        DBTimeProfile.setThreshold(threshold);

        LOG.debug(" ----------- end of  init   config  -----------");
        initialized = true;
    }

}
